@@ -214,3 +214,38 @@ class jac_tests(TestCaseHelper, TestCase):
             api_name="walker_run", params={"name": "init"}
         )["report"]
         self.assertEqual(report[0]["name"], "daman@gmail.com")
+
+    def test_root_is_node_type(self):
+        self.logger_on()
+        mast = master(h=mem_hook())
+        mast.sentinel_register(name="test", code=jtp.root_is_node_type, auto_run="")
+        report = mast.general_interface_to_api(
+            api_name="walker_run", params={"name": "init"}
+        )
+        self.assertEqual(report["report"][0], "JAC_TYPE.NODE")
+
+    def test_walker_with_exit_after_node(self):
+        mast = master(h=mem_hook())
+        mast.sentinel_register(
+            name="test", code=jtp.walker_with_exit_after_node, auto_run=""
+        )
+        report = mast.general_interface_to_api(
+            api_name="walker_run", params={"name": "init"}
+        )
+        self.assertEqual(report["report"], [1, 1, 3, 1, 3, 1, 3, 1, 3, 43])
+
+    def test_depth_first_take(self):
+        mast = master(h=mem_hook())
+        mast.sentinel_register(name="test", code=jtp.depth_first_take, auto_run="")
+        report = mast.general_interface_to_api(
+            api_name="walker_run", params={"name": "init"}
+        )
+        self.assertEqual(report["report"], [1, 2, 3, 4, 5, 6, 7])
+
+    def test_breadth_first_take(self):
+        mast = master(h=mem_hook())
+        mast.sentinel_register(name="test", code=jtp.breadth_first_take, auto_run="")
+        report = mast.general_interface_to_api(
+            api_name="walker_run", params={"name": "init"}
+        )
+        self.assertEqual(report["report"], [1, 2, 5, 3, 4, 6, 7])
